@@ -77,12 +77,12 @@ module ActiveSupport
       end
 
       def write(name, value, options = nil)
-        options = merged_options(options)
-        instrument(:write, name, options) do |payload|
+        options = merged_options(options.to_h.symbolize_keys)
+        instrument(:write, name, options) do |_payload|
           if options[:expires_in].present? && options[:race_condition_ttl].present? && options[:raw].blank?
             options[:expires_in] = options[:expires_in].to_f + options[:race_condition_ttl].to_f
           end
-          entry = options[:raw].present? ? value : Entry.new(value, options)
+          entry = options[:raw].present? ? value : Entry.new(value, **options)
           write_entry(normalize_key(name, options), entry, options)
         end
       end
@@ -302,7 +302,7 @@ module ActiveSupport
         #
         # It's really needed and use
         #
-        def delete_entry(key, options)
+        def delete_entry(key, **options)
           failsafe(:delete_entry, returning: false) do
             with { |c| c.del key }
           end
