@@ -26,6 +26,13 @@ describe ActiveSupport::Cache::RedisStore do
     end
   end
 
+  it "uses redis client passed as an option" do
+    redis = Redis.new(url: "redis://127.0.0.1:6380/1")
+    store = ActiveSupport::Cache::RedisStore.new(client: redis)
+
+    store.data.must_equal(redis)
+  end
+
   it "connects using an hash of options" do
     address = { host: '127.0.0.1', port: '6380', db: '1' }
     store = ActiveSupport::Cache::RedisStore.new(address.merge(pool_size: 5, pool_timeout: 10))
@@ -91,6 +98,11 @@ describe ActiveSupport::Cache::RedisStore do
     underlying_store.must_be_instance_of(::Redis::Store)
   end
 
+  it "creates a normal store when given nil" do
+    underlying_store = instantiate_store nil
+    underlying_store.must_be_instance_of(::Redis::Store)
+  end
+
   it "creates a normal store when given options only" do
     underlying_store = instantiate_store(:expires_in => 1.second)
     underlying_store.must_be_instance_of(::Redis::Store)
@@ -323,6 +335,24 @@ describe ActiveSupport::Cache::RedisStore do
     end
   end
 
+  it "increments a key with expiration time" do
+    with_store_management do |store|
+      store.increment "counter", 1, :expires_in => 1.second
+      store.read("counter", :raw => true).to_i.must_equal(1)
+      sleep 2
+      store.read("counter", :raw => true).must_be_nil
+    end
+  end
+
+  it "decrements a key with expiration time" do
+    with_store_management do |store|
+      store.decrement "counter", 1, :expires_in => 1.second
+      store.read("counter", :raw => true).to_i.must_equal(-1)
+      sleep 2
+      store.read("counter", :raw => true).must_be_nil
+    end
+  end
+
   it "clears the store" do
     with_store_management do |store|
       store.clear
@@ -365,7 +395,7 @@ describe ActiveSupport::Cache::RedisStore do
 
   describe "race_condition_ttl on fetch" do
     it "persist entry for longer than given ttl" do
-      options = { force: true, expires_in: 1.second, race_condition_ttl: 2.seconds }
+      options = { force: true, expires_in: 1.second, race_condition_ttl: 2.seconds, version: Time.now.to_i }
       @store.fetch("rabbit", options) { @rabbit }
       sleep 1.1
       @store.delete("rabbit").must_equal(1)
@@ -373,12 +403,12 @@ describe ActiveSupport::Cache::RedisStore do
 
     it "limits stampede time to read-write duration" do
       first_rabbit = second_rabbit = nil
-      options = { force: true, expires_in: 1.second, race_condition_ttl: 2.seconds }
+      options = { force: true, expires_in: 1.second, race_condition_ttl: 2.seconds, version: Time.now.to_i }
       @store.fetch("rabbit", options) { @rabbit }
       sleep 1
 
       th1 = Thread.new do
-        first_rabbit = @store.fetch("rabbit", race_condition_ttl: 2) do
+        first_rabbit = @store.fetch("rabbit", options) do
           sleep 1
           @white_rabbit
         end
